#!/usr/bin/env node
const { fork } = require('child_process');
const parse = require('yargs-parser');
const chokidar = require('chokidar');
const path = require('path');
const log = require('../dist/utils/log');

let child = null;
const rawArgv = parse(process.argv.slice(2));
const scriptPath = require.resolve('./child-process-start.js');
const configPath = path.resolve(rawArgv.config || 'build.json');

function restartProcess() {
  child = fork(scriptPath, process.argv.slice(2));
  child.on('message', (data) => {
    if (process.send) {
      process.send(data);
    }
  });

  child.on('exit', (code) => {
    if (code) {
      process.exit(code);
    }
  });
}

const onUserChange = () => {
  console.log('\n');
  log.info('build.json has been changed');
  log.info('restart dev server');
  // add process env for mark restart dev process
  process.env.RESTART_DEV = true;
  child.kill();
  restartProcess();
};

restartProcess();

const watcher = chokidar.watch(configPath, {
  ignoreInitial: true,
});

watcher.on('change', onUserChange);

watcher.on('error', (error) => {
  log.error('fail to watch file', error);
  process.exit(1);
});
